<!-- This file is generated from the source code. Edit the files in /packages/hydrogen/src/components/Model3D and run 'yarn generate-docs' at the root of this repo. -->

The `Model3D` component renders a 3D model (with the `model-viewer` tag) for
the Storefront API's [`Model3d` object](/api/storefront/reference/products/model3d).

## Example code

```tsx
import {Model3D} from '@shopify/hydrogen';
import gql from 'graphql-tag';

const QUERY = gql`
  ${Model3D.Fragment}

  query Products {
    products(first: 5) {
      edges {
        node {
          id
          title
          handle
          media(first: 1) {
            edges {
              node {
                ... on Model3D {
                  mediaContentType
                  ...Model3DFragment
                }
              }
            }
          }
        }
      }
    }
  }
`;

export default function MyProductModel() {
  const {data} = useShopQuery({query: QUERY});

  const firstMediaElement = data.products.edges[0].node.media.edges[0].node;
  if (firstMediaElement.mediaContentType === 'MODEL_3D') {
    return <Model3D model={firstMediaElement} />;
  }
}
```

## Props

| Name                        | Type                                                                                                   | Description                                                                                                                                                                                                                                                                                                                      |
| --------------------------- | ------------------------------------------------------------------------------------------------------ | -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| as?                         | <code>ReactNode</code>                                                                                 | A `ReactNode` element.                                                                                                                                                                                                                                                                                                           |
| children?                   | <code>ReactNode</code>                                                                                 | A function that takes an object return by the `useMoney` hook and returns a `ReactNode`.                                                                                                                                                                                                                                         |
| model                       | <code>Unknown<<wbr>UndocumentedType, UndocumentedType, UndocumentedType, UndocumentedType<wbr>></code> | An object with the same fields as the [GraphQL fragment](#graphql-fragment).                                                                                                                                                                                                                                                     |
| loading?                    | <code>"auto" &#124; "lazy" &#124; "eager"</code>                                                       | A string of either `auto`, `lazy`, or `eager` to indicate the conditions for preloading. Refer to [`loading` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-loading-attributes-loading).                                                                                           |
| reveal?                     | <code>"auto" &#124; "interaction" &#124; "manual"</code>                                               | A string of either `auto`, `interaction`, or `manual` to indicate when the model should be revealed. Refer to [`reveal` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-loading-attributes-reveal).                                                                                 |
| ar?                         | <code>boolean</code>                                                                                   | A boolean to enable an AR experience. Refer to [`ar` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-augmentedreality-attributes-ar).                                                                                                                                               |
| arModes?                    | <code>"webxr" &#124; "scene-viewer" &#124; "quick-look"</code>                                         | A prioritized list of `webxr`, `scene-viewer`, and/or `quick-look` to indicate the types of AR experiences to enable. Refer to [`ar-modes` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-augmentedreality-attributes-arModes).                                                    |
| arScale?                    | <code>"auto" &#124; "fixed"</code>                                                                     | A string of `auto` or `fixed` to control the scaling behaviour. Refer to [`ar-scale` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-augmentedreality-attributes-arScale).                                                                                                          |
| arPlacement?                | <code>"floor" &#124; "wall"</code>                                                                     | A styring of either `floor` or `wall` to indicate where to place the object in AR. Refer to [`ar-placement` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-augmentedreality-attributes-arPlacement).                                                                               |
| iosSrc?                     | <code>string</code>                                                                                    | The url to a USDZ model which will be used on supported iOS 12+ devices via AR Quick Look on Safari. Refer to [`ios-source` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-augmentedreality-attributes-iosSrc).                                                                    |
| cameraControls?             | <code>boolean</code>                                                                                   | A boolean to enable camera controls. Refer to [`attributes` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#stagingandcameras-attributes).                                                                                                                                                    |
| touchAction?                | <code>"pan-x" &#124; "pan-y" &#124; "none"</code>                                                      | A string of `pan-x`, `pan-y`, or `none`. Refer to [`touch-action` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-stagingandcameras-attributes-touch-action).                                                                                                                       |
| disableZoom?                | <code>boolean</code>                                                                                   | A boolean to disable zoom. Refer to [`disable-zoom` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-stagingandcameras-attributes-disable-zoom).                                                                                                                                     |
| orbitSensitivity?           | <code>number</code>                                                                                    | A number to adjust the speed of theta and phi orbit interactions. Refer to [`orbit-sensitivity` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-stagingandcameras-attributes-orbitSensitivity).                                                                                     |
| autoRotate?                 | <code>boolean</code>                                                                                   | A boolean to enable auto rotate. Refer to [`auto-rotate` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-stagingandcameras-attributes-autoRotate).                                                                                                                                  |
| autoRotateDelay?            | <code>number</code>                                                                                    | A number in milliseconds to specify the delay before auto rotation begins. Refer to [`auto-rotate-delay` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-stagingandcameras-attributes-autoRotateDelay).                                                                             |
| rotationPerSecond?          | <code>string</code>                                                                                    | The speed of auto rotation. Refer to [`rotation-per-second` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-stagingandcameras-attributes-rotationPerSecond).                                                                                                                        |
| interactionPolicy?          | <code>"allow-when-focused" &#124; "always-allow"</code>                                                | A string of either `allow-when-focused` or `always-allow` to indicate whether the viewer requires focus before interacting with it. Refer to [`interaction-policy` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-stagingandcameras-attributes-interactionPolicy).                 |
| interactionPrompt?          | <code>"auto" &#124; "when-focused" &#124; "none"</code>                                                | A string of either 'auto', 'when-focused', or 'none' indicating the conditions under which the visual and audible interaction prompt will display. Refer to [`interaction-prompts` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-stagingandcameras-attributes-interactionPrompt). |
| interactionPromptStyle?     | <code>"wiggle" &#124; "basic"</code>                                                                   | A string of either `wiggle` or `basic` indicating the presentation style of the interaction-prompt when it is raised. Refer to [`interaction-prompt-style` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-stagingandcameras-attributes-interactionPromptStyle).                    |
| interactionPromptThreshold? | <code>number</code>                                                                                    | A number to indicate how long the model viewer should wait before prompting the user visually for interaction. Refer to [`interaction-prompt-threshold` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-stagingandcameras-attributes-interactionPromptThreshold).                   |
| cameraOrbit?                | <code>string</code>                                                                                    | A string of the starting orbital position of the camera. Refer to [`camera-orbit` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-stagingandcameras-attributes-cameraOrbit).                                                                                                        |
| cameraTarget?               | <code>string</code>                                                                                    | A string of the point the camera orbits around. Refer to [`camera-target` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-stagingandcameras-attributes-cameraTarget).                                                                                                               |
| fieldOfView?                | <code>string</code>                                                                                    | A string of the vertical field of view of the camera. Refer to [`field-of-view` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-stagingandcameras-attributes-fieldOfView).                                                                                                          |
| maxCameraOrbit?             | <code>string</code>                                                                                    | A string of the maxiumum orbital values of the camera. Refer to [`max-camera-orbit` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-stagingandcameras-attributes-maxCameraOrbit).                                                                                                   |
| minCameraOrbit?             | <code>string</code>                                                                                    | A string of the minimum orbital values of the camera. Refer to [`min-camera-orbit` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-stagingandcameras-attributes-minCameraOrbit).                                                                                                    |
| maxFieldOfView?             | <code>number</code>                                                                                    | A number indicating the max field of view of the camera. Refer to [`max-field-of-view` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-stagingandcameras-attributes-maxFieldOfView).                                                                                                |
| minFieldOfView?             | <code>number</code>                                                                                    | A number indicating the min field of view of the camera. Refer to [`min-field-of-view` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-stagingandcameras-attributes-minFieldOfView).                                                                                                |
| bounds?                     | <code>"tight" &#124; "legacy"</code>                                                                   | A string of `tight` or `legacy` for calculating the model's bounding box. Refer to [`bounds` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-stagingandcameras-attributes-bounds).                                                                                                  |
| interpolationDecay?         | <code>number</code>                                                                                    | A number indicating the rate of interpolation when the camera or model moves. Refer to [`interpolation-decay` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-stagingandcameras-attributes-interpolationDecay).                                                                     |
| skyboxImage?                | <code>string</code>                                                                                    | A string for the background image of the scene. Refer to [`skybox-image` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-lightingandenv-attributes-skyboxImage).                                                                                                                    |
| environmentImage?           | <code>string</code>                                                                                    | A string to control the environmental reflection of the model. Refer to [`environment-image` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-lightingandenv-attributes-environmentImage).                                                                                           |
| exposure?                   | <code>number</code>                                                                                    | A number indicating the exposure of the model and the skybox. Refer to [`exposure` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-lightingandenv-attributes-exposure).                                                                                                             |
| shadowIntensity?            | <code>number</code>                                                                                    | A number for the opacity of the shadow. Refer to [`shadow-intensity` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-lightingandenv-attributes-shadowIntensity).                                                                                                                    |
| shadowSoftness?             | <code>number</code>                                                                                    | A number for the bluriness of the shadow. Refer to [`shadow-softness` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-lightingandenv-attributes-shadowSoftness).                                                                                                                    |
| animationName?              | <code>string</code>                                                                                    | A string of the animation to play by name. Refer to [`animation-name` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-animation-attributes-animationName).                                                                                                                          |
| animationCrossfadeDuration? | <code>string</code>                                                                                    | A string of the animation crossfade duration between the previous and next animations. Refer to [`animation-cross-fade-duration` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-animation-attributes-animationCrossfadeDuration).                                                  |
| autoplay?                   | <code>boolean</code>                                                                                   | A boolean to enable the model animations. Refer to [`autoplay` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-animation-attributes-autoplay).                                                                                                                                      |
| variantName?                | <code>string</code>                                                                                    | A string to select a model variant by name. Refer to [`variant-name` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-scenegraph-attributes-variantName).                                                                                                                            |
| orientation?                | <code>string</code>                                                                                    | A string to rotate the model. Refer to [`orientation` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-scenegraph-attributes-orientation).                                                                                                                                           |
| scale?                      | <code>string</code>                                                                                    | A string to scale the model. Refer to [`scale` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-scenegraph-attributes-scale).                                                                                                                                                        |
| onError?                    | <code>(event: Event) => void</code>                                                                    | The callback to invoke when the 'error' event is triggered. Refer to [`error` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-loading-events-error).                                                                                                                                |
| onLoad?                     | <code>(event: Event) => void</code>                                                                    | The callback to invoke when the `load` event is triggered. Refer to [`load` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-loading-events-load).                                                                                                                                   |
| onPreload?                  | <code>(event: Event) => void</code>                                                                    | The callback to invoke when the 'preload' event is triggered. Refer to [`preload` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-loading-events-preload).                                                                                                                          |
| onModelVisibility?          | <code>(event: Event) => void</code>                                                                    | The callback to invoke when the 'model-visibility' event is triggered. Refer to [`model-visibility` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-loading-events-modelVisibility).                                                                                                |
| onProgress?                 | <code>(event: Event) => void</code>                                                                    | The callback to invoke when the 'progress' event is triggered. Refer to [`progress` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-loading-events-progress).                                                                                                                       |
| onArStatus?                 | <code>(event: Event) => void</code>                                                                    | The callback to invoke when the 'ar-status' event is triggered. Refer to [`ar-status` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-augmentedreality-events-arStatus).                                                                                                            |
| onArTracking?               | <code>(event: Event) => void</code>                                                                    | The callback to invoke when the 'ar-tracking' event is triggered. Refer to [`ar-tracking` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-augmentedreality-events-arTracking).                                                                                                      |
| onQuickLookButtonTapped?    | <code>(event: Event) => void</code>                                                                    | The callback to invoke when the 'quick-look-button-tapped' event is triggered. Refer to [`quick-look-button-tapped` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-augmentedreality-events-quickLookButtonTapped).                                                                 |
| onCameraChange?             | <code>(event: Event) => void</code>                                                                    | The callback to invoke when the 'camera-change' event is triggered. Refer to [`camera-change` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-stagingandcameras-events-cameraChange).                                                                                               |
| onEnvironmentChange?        | <code>(event: Event) => void</code>                                                                    | The callback to invoke when the 'environment-change' event is triggered. Refer to [`environment-change` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-lightingandenv-events-environmentChange).                                                                                   |
| onPlay?                     | <code>(event: Event) => void</code>                                                                    | The callback to invoke when the 'play' event is triggered. Refer to [`play` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-animation-events-play).                                                                                                                                 |
| onPause?                    | <code>(event: Event) => void</code>                                                                    | The callback to invoke when the 'pause' event is triggered. Refer to [`pause` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-animation-events-pause).                                                                                                                              |
| onSceneGraphReady?          | <code>(event: Event) => void</code>                                                                    | The callback to invoke when the 'scene-graph-ready' event is triggered. Refer to [`scene-graph-ready` in the &lt;model-viewer&gt; documentation](https://modelviewer.dev/docs/index.html#entrydocs-scenegraph-events-sceneGraphReady).                                                                                           |

## Component type

The `Model3D` component is a client component, which means that it renders on the client. For more information about component types, refer to [React Server Components](/api/hydrogen/framework/react-server-components).

## GraphQL fragment

The following fragment is available as a string for your GraphQL query using `Model3DFragment` or `Model3D.Fragment`. Using this fragment ensures that you have all the data necessary for rendering the `Model3D` component.

```graphql
fragment Model3DFragment on Model3d {
  id
  alt
  mediaContentType
  previewImage {
    url
  }
  sources {
    url
  }
}
```

## Related components

- [`MediaFile`](/api/hydrogen/components/primitive/mediafile)
